==> owncloud-9.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/lib/l10n/es_MX.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "¡No se puede escribir en el directorio «config»!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "¡No se puede escribir en el directorio «config»!\n\nNormalmente esto se soluciona dándole al servidor web acceso para escribir en el directorio config. \n\nConfiguración de muestra detectado",
    "See %s" : "ver %s",
    "This can usually be fixed by %sgiving the webserver write access to the config directory%s." : "Normalmente esto se soluciona %s dándole al servidor web acceso para escribir en el directorio config %s",
    "Sample configuration detected" : "Configuración de muestra detectada",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Se detectó que la configuración de muestra se había copiado. Esto puede romper su instalacón y no está respaldado. Por favor lea la documentación antes de realizar cambios en la config.php",
    "Help" : "Ayuda",
    "Personal" : "Personal",
    "Users" : "Usuarios",
    "Admin" : "Administración",
    "No app name specified" : "No se ha especificado nombre de la aplicación",
    "Unknown filetype" : "Tipo de archivo desconocido",
    "Invalid image" : "Imagen inválida",
    "today" : "hoy",
    "yesterday" : "ayer",
    "last month" : "mes pasado",
    "_%n month ago_::_%n months ago_" : ["Hace %n mes","Hace %n meses"],
    "last year" : "año pasado",
    "_%n hour ago_::_%n hours ago_" : ["Hace %n hora","Hace %n horas"],
    "_%n minute ago_::_%n minutes ago_" : ["Hace %n minuto","Hace %n minutos"],
    "seconds ago" : "hace segundos",
    "web services under your control" : "Servicios web bajo su control",
    "App directory already exists" : "El directorio de la aplicación ya existe",
    "Can't create app folder. Please fix permissions. %s" : "No se puede crear la carpeta de la aplicación. Corrija los permisos. %s",
    "No source specified when installing app" : "No se ha especificado origen cuando se ha instalado la aplicación",
    "No href specified when installing app from http" : "No href especificado cuando se ha instalado la aplicación",
    "No path specified when installing app from local file" : "Sin path especificado cuando se ha instalado la aplicación desde el archivo local",
    "Archives of type %s are not supported" : "Archivos de tipo %s no son soportados",
    "Failed to open archive when installing app" : "Fallo de abrir archivo mientras se instala la aplicación",
    "App does not provide an info.xml file" : "La aplicación no suministra un archivo info.xml",
    "App can't be installed because of not allowed code in the App" : "La aplicación no puede ser instalada por tener código no autorizado en la aplicación",
    "App can't be installed because it is not compatible with this version of ownCloud" : "La aplicación no se puede instalar porque no es compatible con esta versión de ownCloud",
    "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "La aplicación no se puede instalar porque contiene la etiqueta\n<shipped>\ntrue\n</shipped>\nque no está permitida para aplicaciones no distribuidas",
    "Application is not enabled" : "La aplicación no está habilitada",
    "Authentication error" : "Error de autenticación",
    "Token expired. Please reload page." : "Token expirado. Por favor, recarga la página.",
    "%s enter the database username." : "%s ingresar el usuario de la base de datos.",
    "%s enter the database name." : "%s ingresar el nombre de la base de datos",
    "%s you may not use dots in the database name" : "%s puede utilizar puntos en el nombre de la base de datos",
    "Oracle connection could not be established" : "No se pudo establecer la conexión a Oracle",
    "Oracle username and/or password not valid" : "Usuario y/o contraseña de Oracle no válidos",
    "DB Error: \"%s\"" : "Error BD: \"%s\"",
    "Offending command was: \"%s\"" : "Comando infractor: \"%s\"",
    "You need to enter either an existing account or the administrator." : "Tiene que ingresar una cuenta existente o la del administrador.",
    "Offending command was: \"%s\", name: %s, password: %s" : "Comando infractor: \"%s\", nombre: %s, contraseña: %s",
    "PostgreSQL username and/or password not valid" : "Usuario y/o contraseña de PostgreSQL no válidos",
    "Set an admin username." : "Configurar un nombre de usuario del administrador",
    "Set an admin password." : "Configurar la contraseña del administrador.",
    "%s shared »%s« with you" : "%s ha compartido  »%s« contigo",
    "Could not find category \"%s\"" : "No puede encontrar la categoria \"%s\"",
    "Apps" : "Aplicaciones",
    "A valid username must be provided" : "Se debe proporcionar un nombre de usuario válido",
    "A valid password must be provided" : "Se debe proporcionar una contraseña válida"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-9.1.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/lib/l10n/es_MX.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "¡No se puede escribir en el directorio «config»!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "¡No se puede escribir en el directorio «config»!\n\nNormalmente esto se soluciona dándole al servidor web acceso para escribir en el directorio config. \n\nConfiguración de muestra detectado",
    "See %s" : "ver %s",
    "This can usually be fixed by %sgiving the webserver write access to the config directory%s." : "Normalmente esto se soluciona %s dándole al servidor web acceso para escribir en el directorio config %s",
    "Sample configuration detected" : "Configuración de muestra detectada",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Se detectó que la configuración de muestra se había copiado. Esto puede romper su instalacón y no está respaldado. Por favor lea la documentación antes de realizar cambios en la config.php",
    "Unknown filetype" : "Tipo de archivo desconocido",
    "Invalid image" : "Imagen inválida",
    "today" : "hoy",
    "yesterday" : "ayer",
    "last month" : "mes pasado",
    "_%n month ago_::_%n months ago_" : ["Hace %n mes","Hace %n meses"],
    "last year" : "año pasado",
    "_%n hour ago_::_%n hours ago_" : ["Hace %n hora","Hace %n horas"],
    "_%n minute ago_::_%n minutes ago_" : ["Hace %n minuto","Hace %n minutos"],
    "seconds ago" : "hace segundos",
    "App directory already exists" : "El directorio de la aplicación ya existe",
    "Can't create app folder. Please fix permissions. %s" : "No se puede crear la carpeta de la aplicación. Corrija los permisos. %s",
    "No source specified when installing app" : "No se ha especificado origen cuando se ha instalado la aplicación",
    "No href specified when installing app from http" : "No href especificado cuando se ha instalado la aplicación",
    "No path specified when installing app from local file" : "Sin path especificado cuando se ha instalado la aplicación desde el archivo local",
    "Archives of type %s are not supported" : "Archivos de tipo %s no son soportados",
    "Failed to open archive when installing app" : "Fallo de abrir archivo mientras se instala la aplicación",
    "App does not provide an info.xml file" : "La aplicación no suministra un archivo info.xml",
    "App can't be installed because of not allowed code in the App" : "La aplicación no puede ser instalada por tener código no autorizado en la aplicación",
    "App can't be installed because it is not compatible with this version of ownCloud" : "La aplicación no se puede instalar porque no es compatible con esta versión de ownCloud",
    "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "La aplicación no se puede instalar porque contiene la etiqueta\n<shipped>\ntrue\n</shipped>\nque no está permitida para aplicaciones no distribuidas",
    "%s enter the database username." : "%s ingresar el usuario de la base de datos.",
    "%s enter the database name." : "%s ingresar el nombre de la base de datos",
    "%s you may not use dots in the database name" : "%s puede utilizar puntos en el nombre de la base de datos",
    "Oracle connection could not be established" : "No se pudo establecer la conexión a Oracle",
    "Oracle username and/or password not valid" : "Usuario y/o contraseña de Oracle no válidos",
    "DB Error: \"%s\"" : "Error BD: \"%s\"",
    "Offending command was: \"%s\"" : "Comando infractor: \"%s\"",
    "You need to enter either an existing account or the administrator." : "Tiene que ingresar una cuenta existente o la del administrador.",
    "Offending command was: \"%s\", name: %s, password: %s" : "Comando infractor: \"%s\", nombre: %s, contraseña: %s",
    "PostgreSQL username and/or password not valid" : "Usuario y/o contraseña de PostgreSQL no válidos",
    "Set an admin username." : "Configurar un nombre de usuario del administrador",
    "Set an admin password." : "Configurar la contraseña del administrador.",
    "%s shared »%s« with you" : "%s ha compartido  »%s« contigo",
    "Could not find category \"%s\"" : "No puede encontrar la categoria \"%s\"",
    "Apps" : "Aplicaciones",
    "A valid username must be provided" : "Se debe proporcionar un nombre de usuario válido",
    "A valid password must be provided" : "Se debe proporcionar una contraseña válida",
    "Help" : "Ayuda",
    "Personal" : "Personal",
    "Users" : "Usuarios",
    "Admin" : "Administración",
    "No app name specified" : "No se ha especificado nombre de la aplicación",
    "web services under your control" : "Servicios web bajo su control",
    "Application is not enabled" : "La aplicación no está habilitada",
    "Authentication error" : "Error de autenticación",
    "Token expired. Please reload page." : "Token expirado. Por favor, recarga la página."
},
"nplurals=2; plural=(n != 1);");
